export class OverwolfPlugin {
    #pluginName;
    #plugin = null;
    #loadingPromise = null;
    constructor(pluginName) {
        this.#pluginName = pluginName;
    }
    get plugin() {
        if (this.#plugin !== null) {
            return this.#plugin;
        }
        throw new Error('plugin not initialized');
    }
    #loadPluginPromise() {
        return new Promise((resolve, reject) => {
            overwolf.extensions.current.getExtraObject(this.#pluginName, result => {
                if (result.success && result.object) {
                    resolve(result.object);
                }
                else {
                    const msg = `Could not load ${this.#pluginName}: ${JSON.stringify(result)}`;
                    console.warn(`OverwolfPlugin.load(): error: ${msg}`);
                    reject(msg);
                }
            });
        });
    }
    async loadPlugin() {
        if (this.#plugin) {
            return this.#plugin;
        }
        if (!this.#loadingPromise) {
            this.#loadingPromise = this.#loadPluginPromise();
        }
        this.#plugin = await this.#loadingPromise;
        this.#loadingPromise = null;
        return this.#plugin;
    }
}
//# sourceMappingURL=overwolf-plugin.js.map