/// <reference types="@overwolf/types" />
export declare const enum ViewportType {
    Game = "Game",
    Monitor = "Monitor"
}
export declare type Viewport = {
    hash: string;
    name: string;
    id: string | number;
    type: ViewportType;
    monitorHandle: {
        value: number;
    };
    width: number;
    height: number;
    x: number;
    y: number;
    scale: number;
    isPrimary: boolean;
    inFocus: boolean;
};
export declare class OverwolfWindow {
    #private;
    constructor(name: string);
    restore(): Promise<void>;
    minimize(): Promise<void>;
    maximize(): Promise<void>;
    hide(): Promise<void>;
    changeSize(width: number, height: number, autoDpiResize?: boolean): Promise<void>;
    changePosition(left: number, top: number): Promise<void>;
    dragMove(): Promise<overwolf.windows.DragMovedResult>;
    dragResize(edge: overwolf.windows.enums.WindowDragEdge): Promise<void>;
    getWindowState(): Promise<overwolf.windows.GetWindowStateResult>;
    setTopmost(shouldBeTopmost: boolean): Promise<void>;
    sendToBack(): Promise<void>;
    bringToFront(grabFocus: boolean): Promise<void>;
    setPosition(properties: overwolf.windows.SetWindowPositionProperties): Promise<void>;
    close(): Promise<void>;
    toggle(): Promise<void>;
    setZoom(zoomFactor: number): Promise<void>;
    center(): Promise<void>;
    static getWindowsStates(): Promise<overwolf.windows.GetWindowsStatesResult>;
    static getViewportSize(): Promise<{
        width: number;
        height: number;
    }>;
    static getMonitorsList(): Promise<overwolf.utils.getMonitorsListResult>;
    static isWindowVisibleToUser(): Promise<overwolf.windows.IsWindowVisibleToUserResult>;
    centerInViewport(viewport: Viewport): Promise<void>;
    private static makeViewportWithUid;
    private static getGameViewport;
    static getViewportsList(): Promise<Viewport[]>;
    static getPrimaryViewport(): Promise<Viewport | null>;
    static getSecondaryViewport(): Promise<Viewport | null>;
}
declare type OverwolfWindowErrorProps = {
    result: overwolf.Result;
    args?: (null | string | number | boolean | overwolf.windows.SetWindowPositionProperties | overwolf.windows.ChangeWindowSizeParams)[];
};
export declare class OverwolfWindowError extends Error {
    constructor({ result, args }: OverwolfWindowErrorProps);
}
export {};
//# sourceMappingURL=overwolf-window.d.ts.map