import { EventEmitter } from './event-emitter';
export class Profile extends EventEmitter {
    #started;
    #onLoginStateChangedBound;
    #onSubscriptionChangedBound;
    constructor() {
        super();
        this.#onLoginStateChangedBound = this.#onLoginStateChanged.bind(this);
        this.#onSubscriptionChangedBound = this.#onSubscriptionChanged.bind(this);
        this.#started = false;
    }
    start() {
        if (this.#started) {
            return;
        }
        overwolf.profile.onLoginStateChanged
            .addListener(this.#onLoginStateChangedBound);
        overwolf.profile.subscriptions.onSubscriptionChanged
            .addListener(this.#onSubscriptionChangedBound);
        this.#started = true;
    }
    /** Remove all listeners */
    destroy() {
        overwolf.profile.onLoginStateChanged
            .removeListener(this.#onLoginStateChangedBound);
        overwolf.profile.subscriptions.onSubscriptionChanged
            .removeListener(this.#onSubscriptionChangedBound);
        this.#started = false;
    }
    #onLoginStateChanged(e) {
        this.emit('login', e);
    }
    #onSubscriptionChanged(e) {
        this.emit('subscription', e);
    }
    getCurrentUser() {
        return new Promise(resolve => {
            overwolf.profile.getCurrentUser(resolve);
        });
    }
    getActivePlans() {
        return new Promise(resolve => {
            overwolf.profile.subscriptions.getActivePlans(resolve);
        });
    }
    getDetailedActivePlans() {
        return new Promise(resolve => {
            overwolf.profile.subscriptions.getDetailedActivePlans(resolve);
        });
    }
    showSubscriptionsInApp(planId, theme) {
        return new Promise(resolve => {
            overwolf.profile.subscriptions.inapp.show(planId, theme, () => resolve());
        });
    }
    hideSubscriptionsInApp() {
        return new Promise(resolve => {
            overwolf.profile.subscriptions.inapp.hide(() => resolve());
        });
    }
}
//# sourceMappingURL=profile.js.map