import { EventEmitter } from '.';
interface StateSubscription<StateMap> {
    readonly on: EventEmitter<StateMap>['on'];
    readonly off: EventEmitter<StateMap>['off'];
    readonly addListener: EventEmitter<StateMap>['addListener'];
    readonly removeListener: EventEmitter<StateMap>['removeListener'];
}
export declare type State<T> = T & StateSubscription<T>;
export declare class StateManager<StateMapT extends Record<string, any>> extends EventEmitter<StateMapT> {
    #private;
    readonly globalName: string;
    constructor(globalName: string, initialState: StateMapT, persistent?: boolean);
    has(key: string): boolean;
    get<Key extends keyof StateMapT>(key: Key): StateMapT[Key];
    set<Key extends keyof StateMapT>(key: Key, value: StateMapT[Key]): void;
    replaceState(state: StateMapT): void;
    clearPersistentState(): void;
}
/** Read-only wrapper of the StateManager */
export declare class StateClient<StateMapT extends Record<string, any>> {
    #private;
    readonly globalName: string;
    constructor(globalName: string);
    readonly addListener: <EventName extends keyof StateMapT>(eventName: EventName, listener: [StateMapT[EventName]] extends [undefined] ? () => void : (event: StateMapT[EventName]) => void, ref?: any) => void;
    readonly on: (listenersBundle: { readonly [EventName in keyof StateMapT]?: ([StateMapT[EventName]] extends [undefined] ? () => void : (event: StateMapT[EventName]) => void) | undefined; }, ref?: any) => void;
    readonly off: <EventName extends keyof StateMapT>(eventNames: EventName[], ref: any) => void;
    readonly removeListener: <EventName extends keyof StateMapT>(eventName: EventName, ref: any) => void;
    readonly has: (key: string) => boolean;
    readonly get: <Key extends keyof StateMapT>(key: Key) => StateMapT[Key];
}
export declare function makeNiceState<StateMapT extends Record<string, any>>(manager: StateManager<StateMapT>): State<StateMapT>;
export declare function makeNiceStateClient<StateMapT extends Record<string, any>>(globalName: string): State<StateMapT>;
export {};
//# sourceMappingURL=state.d.ts.map